scsihotswap(1M)

scsihotswap - perform hot plug or unplug of scsi device

As shipped in IRIX 6.5. First release of IRIX 6.5.

NAME
     scsihotswap - perform hot plug or unplug of scsi device

SYNOPSIS
     scsihotswap [ options ]


DESCRIPTION
     scsihotswap allows a user to hot plug or unplug a scsi device assuming it
     is not a primary resource (such as the system disk).  There are four
     required options.  These indicate whether to perform a plug or an unplug
     and provide a device, bus, and file system name for the operation.  An
     additional argument is needed to specify the disk is park of an xlv
     volume.

     The required options are:

     -u or -p     Indicate whether operation is an (u)nplug or a (p)lug.

     -d device    In the case of unplug this should be the appropriate device
                  in /dev/scsi, and in the case of plug it should be the
                  appropriate device in /dev/dsk.

     -b bus       Specify the scsi bus for the device.

     -f fsname or -n
                  If a mount (plug) or unmount (unplug) is desired then
                  specify the file system name in fsname.  If none is desired
                  then explicitly specify -n to acknowledge this condition.

     -s fstype    This is required only for a hot plug and indicates the type
                  of file system, such as xfs or efs.

     Additional options:

     -x           Indicate this disk is part of an xlv volume.

     -t timeout   Specify the number of seconds the command will wait while
                  the drive is inserted or removed.  This default value is 30.

WARNINGS
     Care should be take when using the scsihotswap command.  There are
     periods when the scsi bus is in a sensitive state.  The command should
     always be allowed to continue to completion.  Make sure the drive is
     available.  If the drive can not be inserted in the requested time do NOT
     kill the command half way through, let it finish without the drive
     inserted and re-try again later.  Killing the command during will leave
     the scsi bus in a bad state.  Also to help ensure command success the
     file system being unmounted should not currently be in use.
Examples
     The following command could be used to unmount and unplug a scsi disk
     using controller 0 with id 3 and mounted as /x:

     scsihotswap -u -d /dev/scsi/sc0d3l0 -b 0 -f /x

     The following command could be used to plug and mount the same disk:

     scsihotswap -p -d /dev/dsk/dks0d3s7 -b 0 -f /x -s xfs

SEE ALSO
     scsiha(7M).